"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SolanaSigner = void 0;
const platform_1 = require("../platform");
const debug_1 = require("./debug");
class SolanaSigner {
    _chain;
    _keypair;
    _rpc;
    _debug;
    constructor(_chain, _keypair, _rpc, _debug = false) {
        this._chain = _chain;
        this._keypair = _keypair;
        this._rpc = _rpc;
        this._debug = _debug;
    }
    chain() {
        return this._chain;
    }
    address() {
        return this._keypair.publicKey.toBase58();
    }
    async sign(tx) {
        const { blockhash } = await platform_1.SolanaPlatform.latestBlock(this._rpc);
        const signed = [];
        for (const txn of tx) {
            const { description, transaction: { transaction, signers: extraSigners }, } = txn;
            console.log(`Signing: ${description} for ${this.address()}`);
            if (this._debug)
                (0, debug_1.logTxDetails)(transaction);
            transaction.recentBlockhash = blockhash;
            transaction.partialSign(this._keypair, ...(extraSigners ?? []));
            signed.push(transaction.serialize());
        }
        return signed;
    }
}
exports.SolanaSigner = SolanaSigner;
//# sourceMappingURL=signer.js.map